==> em_tasks-0.1.63-py2.py3-none-any.whl: em_tasks/utils/pipelines/ebay_products_filter.py <==
import re

from em_tasks.utils.pipelines.base import BasePipeline
from em_tasks import logger


class EbayProductsFilterPipeline(BasePipeline):
  def __init__(self, max_shipping_days=14, min_seller_rating=98):
    self.max_shipping_days = max_shipping_days
    self.min_seller_rating = min_seller_rating
    self.used_pattern = re.compile(r'.*(used|open in box).*')

  def execute(self, product):
    result = self.check_product(product)
    passed = result.get('passed', True)
    if passed:
      return product

  def check_product(self, product):
    exist = product.get('existence', True)
    if not exist:
      return {'passed': False, 'reason': '[NotExist]'}

    has_only_default_variant = product.get('has_only_default_variant', True)
    if not has_only_default_variant:
      return {'passed': False, 'reason': '[MultipleVariant]'}

    shipping_days_max = product.get('shipping_days_max', None)
    if shipping_days_max and shipping_days_max > self.max_shipping_days:
      return {'passed': False, 'reason': '[ShippingTimeInvalid] Max: {}'.format(shipping_days_max)}

    seller_rating = product.get('seller_rating', 0)
    if seller_rating and seller_rating < self.min_seller_rating:
      return {
        'passed': False,
        'reason': '[SellerRatingInvalid] ProductId: {}, SellerRating: {}'.format(product['product_id'], seller_rating)
      }

    title = product.get('title', '').lower()
    description = product.get('description', '')
    if title.find('expir') != -1 or (description and self.used_pattern.match(description.lower())):
      logger.debug(
        '[UsedOrExpire] ProductId: %s, Title: %s',
        product['product_id'], title)
      return {'passed': False, 'reason': '[UsedOrExpire] ProductId: {}, Title: {}'.format(product['product_id'], title)}

    return {'passed': True, 'reason': ''}

==> em_tasks-0.1.65-py2.py3-none-any.whl: em_tasks/utils/pipelines/ebay_products_filter.py <==
import re

from em_tasks.utils.pipelines.base import BasePipeline
from em_tasks import logger


class EbayProductsFilterPipeline(BasePipeline):
  def __init__(self, max_shipping_days=20, min_seller_rating=98):
    self.max_shipping_days = max_shipping_days
    self.min_seller_rating = min_seller_rating
    self.used_pattern = re.compile(r'.*(used|open in box).*')
    self.source = 'Ebay_US'

  def execute(self, product):
    result = self.check_product(product)
    passed = result.get('passed', True)
    if passed:
      product['source'] = self.source
      return product

  def check_product(self, product):
    exist = product.get('existence', True)
    if not exist:
      return {'passed': False, 'reason': '[NotExist]'}

    has_only_default_variant = product.get('has_only_default_variant', True)
    if not has_only_default_variant:
      return {'passed': False, 'reason': '[MultipleVariant]'}

    shipping_days_max = product.get('shipping_days_max', None)
    if shipping_days_max and shipping_days_max > self.max_shipping_days:
      return {'passed': False, 'reason': '[ShippingTimeInvalid] Max: {}'.format(shipping_days_max)}

    seller_rating = product.get('seller_rating', 0)
    if seller_rating and seller_rating < self.min_seller_rating:
      return {
        'passed': False,
        'reason': '[SellerRatingInvalid] ProductId: {}, SellerRating: {}'.format(product['product_id'], seller_rating)
      }

    title = product.get('title', '').lower()
    description = product.get('description', '')
    if title.find('expir') != -1 or self.used_pattern.match(title):
      logger.debug(
        '[UsedOrExpire] ProductId: %s, Title: %s',
        product['product_id'], title)
      return {'passed': False, 'reason': '[UsedOrExpire] ProductId: {}, Title: {}'.format(product['product_id'], title)}

    return {'passed': True, 'reason': ''}
